# VAEDE

[![codecov](https://codecov.io/gh/HeosSacer/VAEDE/branch/main/graph/badge.svg?token=VAEDE_token_here)](https://codecov.io/gh/HeosSacer/VAEDE)
[![CI](https://github.com/HeosSacer/VAEDE/actions/workflows/main.yml/badge.svg)](https://github.com/HeosSacer/VAEDE/actions/workflows/main.yml)

Variational Auto Encoder for distribution estimation

- [FastAPI-Project-Template](https://github.com/rochacbruno/fastapi-project-template/) The base to start an openapi project featuring: SQLModel, Typer, FastAPI, JWT Token Auth, Interactive Shell, Management Commands.

## Install it from PyPI

```bash
pip install vaede
```

## Usage

```py
from vaede import BaseClass
from vaede import base_function

BaseClass().base_method()
base_function()
```

```bash
$ python -m vaede
#or
$ vaede
```

## Development

Read the [CONTRIBUTING.md](CONTRIBUTING.md) file.
